/*
 * ATTENTION: The "eval" devtool has been used (maybe by default in mode: "development").
 * This devtool is neither made for production nor for readable output files.
 * It uses "eval()" calls to create a separate source file in the browser devtools.
 * If you are trying to read the output file, select a different devtool (https://webpack.js.org/configuration/devtool/)
 * or disable the default devtool with "devtool: false".
 * If you are looking for production-ready output files, see mode: "production" (https://webpack.js.org/configuration/mode/).
 */
define(() => { return /******/ (() => { // webpackBootstrap
/******/ 	var __webpack_modules__ = ({

/***/ "./src/extension.ts":
/*!**************************!*\
  !*** ./src/extension.ts ***!
  \**************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _index__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./index */ \"./src/index.ts\");\n/* harmony reexport (unknown) */ var __WEBPACK_REEXPORT_OBJECT__ = {};\n/* harmony reexport (unknown) */ for(const __WEBPACK_IMPORT_KEY__ in _index__WEBPACK_IMPORTED_MODULE_0__) if(__WEBPACK_IMPORT_KEY__ !== \"default\") __WEBPACK_REEXPORT_OBJECT__[__WEBPACK_IMPORT_KEY__] = () => _index__WEBPACK_IMPORTED_MODULE_0__[__WEBPACK_IMPORT_KEY__]\n/* harmony reexport (unknown) */ __webpack_require__.d(__webpack_exports__, __WEBPACK_REEXPORT_OBJECT__);\n// For licensing see accompanying LICENSE file.\n// Copyright (C) 2023 Apple Inc. All Rights Reserved.\n// Entry point for the notebook bundle containing custom model definitions.\n//\n// Setup notebook base URL\n//\n// Some static assets may be required by the custom widget javascript. The base\n// url for the notebook is not known at build time and is therefore computed\n// dynamically.\n// eslint-disable-next-line @typescript-eslint/no-non-null-assertion\nwindow.__webpack_public_path__ =\n    document.querySelector('body').getAttribute('data-base-url') +\n        'nbextensions/symphony_list';\n\n\n\n//# sourceURL=webpack://symphony-list/./src/extension.ts?");

/***/ }),

/***/ "./src/index.ts":
/*!**********************!*\
  !*** ./src/index.ts ***!
  \**********************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   MODULE_NAME: () => (/* reexport safe */ _version__WEBPACK_IMPORTED_MODULE_0__.MODULE_NAME),\n/* harmony export */   MODULE_VERSION: () => (/* reexport safe */ _version__WEBPACK_IMPORTED_MODULE_0__.MODULE_VERSION)\n/* harmony export */ });\n/* harmony import */ var _version__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./version */ \"./src/version.ts\");\n/* harmony import */ var _widget__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./widget */ \"./src/widget.ts\");\n/* harmony import */ var _widget__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_widget__WEBPACK_IMPORTED_MODULE_1__);\n/* harmony reexport (unknown) */ var __WEBPACK_REEXPORT_OBJECT__ = {};\n/* harmony reexport (unknown) */ for(const __WEBPACK_IMPORT_KEY__ in _widget__WEBPACK_IMPORTED_MODULE_1__) if([\"default\",\"MODULE_NAME\",\"MODULE_VERSION\"].indexOf(__WEBPACK_IMPORT_KEY__) < 0) __WEBPACK_REEXPORT_OBJECT__[__WEBPACK_IMPORT_KEY__] = () => _widget__WEBPACK_IMPORTED_MODULE_1__[__WEBPACK_IMPORT_KEY__]\n/* harmony reexport (unknown) */ __webpack_require__.d(__webpack_exports__, __WEBPACK_REEXPORT_OBJECT__);\n// For licensing see accompanying LICENSE file.\n// Copyright (C) 2023 Apple Inc. All Rights Reserved.\n\n\n\n\n//# sourceURL=webpack://symphony-list/./src/index.ts?");

/***/ }),

/***/ "./src/version.ts":
/*!************************!*\
  !*** ./src/version.ts ***!
  \************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   MODULE_NAME: () => (/* binding */ MODULE_NAME),\n/* harmony export */   MODULE_VERSION: () => (/* binding */ MODULE_VERSION)\n/* harmony export */ });\n// For licensing see accompanying LICENSE file.\n// Copyright (C) 2023 Apple Inc. All Rights Reserved.\n// eslint-disable-next-line @typescript-eslint/no-var-requires\nconst data = __webpack_require__(/*! ../package.json */ \"./package.json\");\n/**\n * The _model_module_version/_view_module_version this package implements.\n *\n * The html widget manager assumes that this is the same as the npm package\n * version number.\n */\nconst MODULE_VERSION = data.version;\n/*\n * The current package name.\n */\nconst MODULE_NAME = data.name;\n\n\n//# sourceURL=webpack://symphony-list/./src/version.ts?");

/***/ }),

/***/ "./src/widget.ts":
/*!***********************!*\
  !*** ./src/widget.ts ***!
  \***********************/
/***/ (() => {

eval("throw new Error(\"Module build failed (from ../../node_modules/ts-loader/index.js):\\nError: TypeScript emitted no output for /Users/fredhohman/Github/apple/ml-symphony/widgets/symphony_list/src/widget.ts.\\n    at makeSourceMapAndFinish (/Users/fredhohman/Github/apple/ml-symphony/node_modules/ts-loader/dist/index.js:52:18)\\n    at successLoader (/Users/fredhohman/Github/apple/ml-symphony/node_modules/ts-loader/dist/index.js:39:5)\\n    at Object.loader (/Users/fredhohman/Github/apple/ml-symphony/node_modules/ts-loader/dist/index.js:22:5)\");\n\n//# sourceURL=webpack://symphony-list/./src/widget.ts?");

/***/ }),

/***/ "./package.json":
/*!**********************!*\
  !*** ./package.json ***!
  \**********************/
/***/ ((module) => {

"use strict";
eval("module.exports = JSON.parse('{\"name\":\"symphony-list\",\"version\":\"1.0.0\",\"description\":\"A list view of all the instances.\",\"private\":true,\"keywords\":[\"jupyter\",\"jupyterlab\",\"jupyterlab-extension\",\"widgets\"],\"files\":[\"lib/**/*.js\",\"dist/*.js\",\"standalone/*\"],\"main\":\"lib/index.js\",\"types\":\"./lib/index.d.ts\",\"homepage\":\"https://github.com/apple/ml-symphony\",\"bugs\":{\"url\":\"https://github.com/apple/ml-symphony/issues\"},\"author\":\"Apple\",\"repository\":{\"type\":\"git\",\"url\":\"https://github.com/apple/ml-symphony\"},\"scripts\":{\"build\":\"webpack --mode=development --progress && jupyter labextension build --development=True .\",\"build:prod\":\"webpack --mode=production && jupyter labextension build .\",\"clean\":\"yarn run clean:lib && yarn run clean:nbextension && yarn run clean:labextension\",\"clean:lib\":\"rimraf lib\",\"clean:labextension\":\"rimraf symphony/labextension\",\"clean:nbextension\":\"rimraf symphony/nbextension/static/index.js\",\"lint\":\"eslint . --ext .ts,.tsx,.svelte --fix\",\"lint:check\":\"eslint . --ext .ts,.tsx,.svelte\",\"prepack\":\"yarn run build:prod\",\"watch\":\"yarn run watch:nbextension\",\"watch:nbextension\":\"webpack --watch --mode=development --progress\",\"watch:labextension\":\"jupyter labextension watch .\",\"dev\":\"yarn run watch & python -m http.server --directory ./symphony_list/standalone 8082\"},\"dependencies\":{\"@apple/symphony-lib\":\"^1.0.0\",\"@jupyter-widgets/base\":\"^1.1.10 || ^2.0.0 || ^3.0.0 || ^4.0.0\",\"arquero\":\"^4.7.2\",\"svelte-infinite-scroll\":\"^2.0.0\"},\"devDependencies\":{\"@fullhuman/postcss-purgecss\":\"^4.0.3\",\"@jupyterlab/builder\":\"^3.1.12\",\"@phosphor/application\":\"^1.6.0\",\"@phosphor/widgets\":\"^1.6.0\",\"@tailwindcss/forms\":\"^0.3.2\",\"@tsconfig/svelte\":\"^2.0.1\",\"@types/webpack-env\":\"^1.13.6\",\"@typescript-eslint/eslint-plugin\":\"^4.31.1\",\"@typescript-eslint/parser\":\"^4.31.1\",\"@webpack-cli/serve\":\"^1.2.2\",\"autoprefixer\":\"^10.3.4\",\"commitizen\":\"^4.2.4\",\"css-loader\":\"^6.2.0\",\"css-minimizer-webpack-plugin\":\"^3.0.1\",\"cz-conventional-changelog\":\"^3.3.0\",\"eslint\":\"^7.4.0\",\"eslint-config-prettier\":\"^8.1.0\",\"eslint-plugin-prettier\":\"^4.0.0\",\"mini-css-extract-plugin\":\"^2.3.0\",\"mkdirp\":\"^1.0.4\",\"postcss\":\"^8.2.10\",\"postcss-extend\":\"^1.0.5\",\"postcss-import\":\"^14.0.1\",\"postcss-load-config\":\"^3.0.1\",\"postcss-loader\":\"^6.1.0\",\"precss\":\"^4.0.0\",\"prettier\":\"^2.4.0\",\"purgecss-from-svelte\":\"^2.0.2\",\"rimraf\":\"^3.0.2\",\"source-map-loader\":\"^3.0.0\",\"style-loader\":\"^3.2.1\",\"svelte\":\"^3.42.5\",\"svelte-loader\":\"^3.1.1\",\"svelte-preprocess\":\"^4.9.4\",\"tailwindcss\":\"^2.2.15\",\"ts-loader\":\"^9.1.0\",\"typescript\":\"~4.4.3\",\"webpack\":\"^5.52.1\",\"webpack-cli\":\"^4.6.0\",\"webpack-dev-server\":\"^4.2.1\",\"yarn-run-all\":\"^3.1.1\"},\"jupyterlab\":{\"extension\":\"lib/index\",\"outputDir\":\"symphony_list/labextension/\",\"sharedPackages\":{\"@jupyter-widgets/base\":{\"bundled\":false,\"singleton\":true}}},\"config\":{\"commitizen\":{\"path\":\"./node_modules/cz-conventional-changelog\"}}}');\n\n//# sourceURL=webpack://symphony-list/./package.json?");

/***/ })

/******/ 	});
/************************************************************************/
/******/ 	// The module cache
/******/ 	var __webpack_module_cache__ = {};
/******/ 	
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/ 		// Check if module is in cache
/******/ 		var cachedModule = __webpack_module_cache__[moduleId];
/******/ 		if (cachedModule !== undefined) {
/******/ 			return cachedModule.exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = __webpack_module_cache__[moduleId] = {
/******/ 			// no module.id needed
/******/ 			// no module.loaded needed
/******/ 			exports: {}
/******/ 		};
/******/ 	
/******/ 		// Execute the module function
/******/ 		__webpack_modules__[moduleId](module, module.exports, __webpack_require__);
/******/ 	
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/ 	
/************************************************************************/
/******/ 	/* webpack/runtime/compat get default export */
/******/ 	(() => {
/******/ 		// getDefaultExport function for compatibility with non-harmony modules
/******/ 		__webpack_require__.n = (module) => {
/******/ 			var getter = module && module.__esModule ?
/******/ 				() => (module['default']) :
/******/ 				() => (module);
/******/ 			__webpack_require__.d(getter, { a: getter });
/******/ 			return getter;
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/define property getters */
/******/ 	(() => {
/******/ 		// define getter functions for harmony exports
/******/ 		__webpack_require__.d = (exports, definition) => {
/******/ 			for(var key in definition) {
/******/ 				if(__webpack_require__.o(definition, key) && !__webpack_require__.o(exports, key)) {
/******/ 					Object.defineProperty(exports, key, { enumerable: true, get: definition[key] });
/******/ 				}
/******/ 			}
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/hasOwnProperty shorthand */
/******/ 	(() => {
/******/ 		__webpack_require__.o = (obj, prop) => (Object.prototype.hasOwnProperty.call(obj, prop))
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/make namespace object */
/******/ 	(() => {
/******/ 		// define __esModule on exports
/******/ 		__webpack_require__.r = (exports) => {
/******/ 			if(typeof Symbol !== 'undefined' && Symbol.toStringTag) {
/******/ 				Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });
/******/ 			}
/******/ 			Object.defineProperty(exports, '__esModule', { value: true });
/******/ 		};
/******/ 	})();
/******/ 	
/************************************************************************/
/******/ 	
/******/ 	// startup
/******/ 	// Load entry module and return exports
/******/ 	// This entry module can't be inlined because the eval devtool is used.
/******/ 	var __webpack_exports__ = __webpack_require__("./src/extension.ts");
/******/ 	
/******/ 	return __webpack_exports__;
/******/ })()
;
});;